/* Tentative CSS for the dictionaries of the FreeDict project
  originally by Piotr Bański (bansp in the domain of o2.pl) */
/* Version: 29 November 2010. License: CC BY-SA 3.0 or GNU GPL 3.0 (choose) */

/* $Id:$ */

/* Note that you may need to CUSTOMIZE this stylesheet! */

/*************** the header part ***************/
title, respStmt, editionStmt, edition, extent, publicationStmt, publisher, availability, sourceDesc, 
fileDesc, encodingDesc, revisionDesc, change, item, pubPlace, list > head {display:block; margin-bottom: 1em}

titleStmt > title, edition { font-weight:bold}

titleStmt > title {font-size:larger; text-align:center}

p title, p name, change title, change name {font-weight:inherit; display:inline}

/* edition > date {margin-left: 1em} */
/* not needed for now, <edition/> is used for version numbering */

edition:before {content: "Version ";  font-weight:bold}

p, list {display:block}
list {margin-left: 1em}

list > head {font-weight:bold}

extent:before {content: "Extent: "}
publisher:before {content: "Publisher: "}
availability:before {content: "Availability: "}
publicationStmt > date:before {content: "Publication date: "}
pubPlace:before {content: "Published at: "}

publicationStmt:before {content: "Publication Statement"; color:blue; font-size:larger}

editionStmt:before {content: "Edition Statement"; color:blue; font-size:larger}

sourceDesc:before {content: "Source Description"; color:blue; font-size:larger}

projectDesc:before {content: "Project Description"; color:blue; font-size:larger}

revisionDesc:before {content: "Change Log"; color:blue; font-size:larger}

respStmt:before, list[type='bulleted'] > item:before {content:"* "}

teiHeader {display:block; margin-bottom: 3em}

name {color:teal}

foreign {font-style:italic}

teiHeader {border-bottom:solid black 1px} 

/*************** dictionary body ***************/
entry, /*dicteg,*/ sense, cit, re, note {display:block}

form, gramGrp, xr, quote, bibl, gloss {display: inline}

gramGrp, /* usg,*/ q, quote {font-style: italic}

gramGrp {color:brown}

/* hiding untyped <note> elements 
note {display:none}
note[type] {display:block}
*/

note[type='style'], note[type='infl-base'], note[type='hint'], note[type='num'] {display:inline}
note[type='style']:before, note[type='infl-base']:before, note[type='hint']:before, note[type='num']:before {content: "("; color:black; font-weight:normal}
note[type='style']:after, note[type='infl-base']:after, note[type='hint']:after, note[type='num']:after {content: ")"; color:black; font-weight:normal}
note[type='cl-agr']:before {content: "(agrees with cl. ";color:navy; font-weight:normal}
note[type='cl-agr']:after {content: ")"; color:navy; font-weight:normal}

note[type='plural-sense'] {color: black}
note[type='plural-form'] {display:inline; color: black}
note[type='plural-sense']:before {content:""}
note[type='plural-form']:before {content:""}

note {color: navy}
note:before {content: "NOTE: "; color: orange; font-weight:bold}


entry {margin:2em}

sense {margin-left: 1em}
sense[n]:before {content:attr(n) "."}
sense:before {content:"• "}

form[type='N']:after {content: " [sg=pl]"}

entry > form > orth {font-weight: bold}
re > form > orth {font-weight: bold}
orth[type=morph]+orth {display: none} /* out */
entry[n='1'] > form > orth:first-child:after {content:"1"; font-size: 0.7em;
    vertical-align: top; bottom: 0.33em}
entry[n='2'] > form > orth:first-child:after {content:"2"; font-size: 0.7em;
    vertical-align: top; bottom: 0.33em}
entry[n='3'] > form > orth:first-child:after {content:"3"; font-size: 0.7em;
    vertical-align: top; bottom: 0.33em}
entry[n='4'] > form > orth:first-child:after {content:"4"; font-size: 0.7em;
    vertical-align: top; bottom: 0.33em}

/* this might be made more universal, though I'm not sure it's worth the time */
orth[type=variant]:before {content: "(also ";font-weight:normal}
orth[type=variant]:after {content: ")";font-weight:normal}

def+xr[type=plural-sense] {display:block}
def+xr[type=plural-sense]:before {content:"· "}
xr[type=plural-sense]:after {content:":"}

cit[type='trans'] {display:inline}
cit[type='dicteg'] {display:block}

cit[type='trans'] > quote {display:inline}
cit[type='trans'] > quote + note {display:inline}

xr[type=cf] {display:block}

ref {color: teal; text-decoration: none}
xr[type=tail_infl] > ref {color: green; }
ref+ref:before {content:"· "; text-decoration: none;}

def+def:before {content:"· "}


/*********** ERRORS ***********/
entry > xr[type=syn] { color: red; font-weight: bold; font-size: larger }
 /* synonyms always for a particular sense */
 
 [rend='red'] {color: red}
 [rend='red']:before {content: "ERROR: "; color: red} /* sometimes the rend can appear on an empty element */
 
 note[type='dunno'] {color: green}
 